@@ -1,7 +1,7 @@
 from pathlib import Path
 from unittest.mock import patch
 
-from src.python_learning_tracker.cli import main
+from python_learning_tracker.cli import main
 
 
 def test_cli_with_mocked_args():
